@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 5                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2015 The PHP Group                                |
+   | Copyright (c) 1997-2014 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -26,9 +26,10 @@
 #include <dmalloc.h>
 #endif
 
-#define PHP_API_VERSION 20121113
+#define PHP_API_VERSION 20131106
 #define PHP_HAVE_STREAMS
 #define YYDEBUG 0
+#define PHP_DEFAULT_CHARSET "UTF-8"
 
 #include "php_version.h"
 #include "zend.h"
@@ -182,6 +183,8 @@ typedef unsigned int socklen_t;
 # endif
 #endif
 
+#include "php_stdint.h"
+
 #include "zend_hash.h"
 #include "zend_alloc.h"
 #include "zend_stack.h"
@@ -400,7 +403,7 @@ END_EXTERN_C()
 
 
 /* Virtual current working directory support */
-#include "tsrm_virtual_cwd.h"
+#include "zend_virtual_cwd.h"
 
 #include "zend_constants.h"
 
